ReducedDaeSystem

Struct ReducedDaeSystem 

pub struct ReducedDaeSystem<S: Scalar> { /* private fields */ }

Implementations

Source

impl<S: Scalar> ReducedDaeSystem<S>

pub fn info(&self) -> &DaeIndexInfo

Get the differentiation info.

pub fn n_diff(&self) -> usize

Get the number of differential variables in the original system.

pub fn augmented_dim(&self) -> usize

Get the augmented system dimension.

pub fn original_dim(&self) -> usize

Get the original system dimension.

pub fn extract_original(&self, y_aug: &[S]) -> Vec<S>

Extract the original state variables from an augmented state vector.

pub fn augment_initial_conditions(&self, t0: S, y0: &[S]) -> Vec<S>

Build augmented initial conditions.

The new variables (time derivatives of algebraic variables) are initialized by evaluating the constraints’ time derivatives at the initial point.