SolverOptions

Struct SolverOptions 

pub struct SolverOptions<S: Scalar> {
    pub rtol: S,
    pub atol: S,
    pub h0: Option<S>,
    pub h_max: S,
    pub h_min: S,
    pub max_steps: usize,
    pub t_eval: Option<Vec<S>>,
    pub dense_output: bool,
    pub events: Vec<Arc<dyn EventFunction<S>>>,
}
Solver options and tolerances.

Cloneable thanks to Arc-wrapped event functions.

Fields

rtol: S

Relative tolerance

atol: S

Absolute tolerance (scalar)

h0: Option<S>

Initial step size (None = auto)

h_max: S

Maximum step size

h_min: S

Minimum step size

max_steps: usize

Maximum number of steps

t_eval: Option<Vec<S>>

Output grid in the integration direction. When Some, each solver returns exactly these (t, y) pairs (Hermite cubic interpolated from accepted step endpoints; endpoints are reproduced bit-exact). When None, the natural adaptive step grid is returned.

dense_output: bool

Enable dense output

events: Vec<Arc<dyn EventFunction<S>>>

Event functions for zero-crossing detection (Arc enables Clone)

Implementations

Source

impl<S: Scalar> SolverOptions<S>

pub fn rtol(self, rtol: S) -> Self

Set relative tolerance.

Examples found in repository?
examples/radau5_step_audit.rs (line 15)
10fn run<F>(name: &str, rhs: F, t0: f64, tf: f64, y0: Vec<f64>, rtol: f64, atol: f64)
11where
12    F: Fn(f64, &[f64], &mut [f64]) + Copy,
13{
14    let problem = OdeProblem::new(rhs, t0, tf, y0.clone());
15    let opts = SolverOptions::default().rtol(rtol).atol(atol);
16    let res = Radau5::solve(&problem, t0, tf, &y0, &opts).expect("solve failed");
17    println!(
18        "{:<32} acc={:>4}  rej={:>3}  rhs={:>5}  jac={:>3}  lu={:>4}",
19        name,
20        res.stats.n_accept,
21        res.stats.n_reject,
22        res.stats.n_eval,
23        res.stats.n_jac,
24        res.stats.n_lu,
25    );
26}
pub fn atol(self, atol: S) -> Self

Set absolute tolerance.

Examples found in repository?
examples/radau5_step_audit.rs (line 15)
10fn run<F>(name: &str, rhs: F, t0: f64, tf: f64, y0: Vec<f64>, rtol: f64, atol: f64)
11where
12    F: Fn(f64, &[f64], &mut [f64]) + Copy,
13{
14    let problem = OdeProblem::new(rhs, t0, tf, y0.clone());
15    let opts = SolverOptions::default().rtol(rtol).atol(atol);
16    let res = Radau5::solve(&problem, t0, tf, &y0, &opts).expect("solve failed");
17    println!(
18        "{:<32} acc={:>4}  rej={:>3}  rhs={:>5}  jac={:>3}  lu={:>4}",
19        name,
20        res.stats.n_accept,
21        res.stats.n_reject,
22        res.stats.n_eval,
23        res.stats.n_jac,
24        res.stats.n_lu,
25    );
26}
pub fn h0(self, h0: S) -> Self

Set initial step size.

pub fn h_max(self, h_max: S) -> Self

Set maximum step size.

pub fn t_eval(self, t_eval: Vec<S>) -> Self

Set evaluation times.

pub fn dense(self) -> Self

Enable dense output.

pub fn max_steps(self, max_steps: usize) -> Self

Set maximum number of steps.

pub fn h_min(self, h_min: S) -> Self

Set minimum step size.

pub fn event(self, event: Box<dyn EventFunction<S>>) -> Self

Add an event function for zero-crossing detection.

Internally converts to Arc to enable Clone on SolverOptions.