UncertainSolverResult

Struct UncertainSolverResult 

pub struct UncertainSolverResult<S: Scalar> {
    pub result: SolverResult<S>,
    pub sigma: Vec<S>,
    pub sensitivities: Option<Vec<Vec<S>>>,
    pub params: Vec<UncertainParam<S>>,
}
ODE result with uncertainty bands.

Fields

result: SolverResult<S>

Base result (nominal trajectory).

sigma: Vec<S>

Standard deviation at each output time, for each component. sigma[i * dim + j] = std dev of component j at time i.

sensitivities: Option<Vec<Vec<S>>>

Sensitivity matrices at each output time (Trajectory mode only). Each entry is a flat row-major matrix of shape (n_states, n_params). sensitivities[i][j * n_params + k] = dy_j/dp_k at time i.

params: Vec<UncertainParam<S>>

Parameter information.

Implementations

Source

impl<S: Scalar> UncertainSolverResult<S>

pub fn sigma_at(&self, i: usize, j: usize) -> S

Get sigma for component j at time index i.

pub fn uncertain_at(&self, i: usize, j: usize) -> Uncertain<S>

Get the uncertain value (mean +/- std) for component j at time index i.

pub fn sensitivity_at(&self, i: usize, j: usize, k: usize) -> Option<S>

Get sensitivity dy_j/dp_k at time index i. Returns None if sensitivities were not computed (Monte Carlo mode).

pub fn len(&self) -> usize

Number of time points.

pub fn is_empty(&self) -> bool

Whether the result is empty.