pub struct PIController<S: Scalar> {
pub safety: S,
pub fac_min: S,
pub fac_max: S,
pub beta1: S,
pub beta2: S,
/* private fields */
}Expand description
PI (Proportional-Integral) step size controller.
This is the standard controller used in most production ODE codes. It provides smoother step size changes than a simple error-based controller.
The new step size is computed as: h_new = h * (1/err)^(beta1/p) * (err_old/err)^(beta2/p)
where p is the method order.
Fields
safety: SSafety factor (typically 0.9)
fac_min: SMinimum step size factor
fac_max: SMaximum step size factor
beta1: SI-controller gain (typically 0.7/p)
beta2: SP-controller gain (typically 0.4/p)
Implementations
Sourceimpl<S: Scalar> PIController<S>
impl<S: Scalar> PIController<S>